# Additional Resources

> GitHub repositories, NGC Catalog, learning paths, and community resources.

## Contents

| Resource | Doc | Description |
|---|---|---|
| [GitHub Repos](github-repos.md) | `docs/resources/github-repos.md` | All NVIDIA AI GitHub repositories |
| [NGC Catalog](ngc-catalog.md) | `docs/resources/ngc-catalog.md` | Container registry and model hub |
| [Learning](learning.md) | `docs/resources/learning.md` | Courses, certifications, and learning paths |
